Structs
- Delegate
Apply Options - Options for delegate command execution.
- Delegate
Apply Result - Result of a delegate command operation.
Enums
- Delegate
Result Kind - The kind of delegate result.
Functions
- apply_
delegate_ update - Apply an update by delegating to a package manager command.
- validate_
command - Validate that a command program is in the allowed safelist.