pub fn validate_command(program: &str) -> Result<(), UpdateKitError>Expand description
Validate that a command program is in the allowed safelist.
pub fn validate_command(program: &str) -> Result<(), UpdateKitError>Validate that a command program is in the allowed safelist.