Module checker

Module checker 

Modules

background
cache
infer_sources
sources

Structs

CheckUpdateOptions
Options for the check_update orchestrator.

Functions

check_update
Orchestrate an update check using the configured sources and cache.
normalize_version
Normalize a version string by stripping a leading ‘v’ and parsing with semver. Returns None if the version string is not valid semver.