pub fn is_cache_stale(entry: &CacheEntry, interval_ms: u64) -> boolExpand description
Check if a cache entry is stale based on the given interval (in milliseconds).
pub fn is_cache_stale(entry: &CacheEntry, interval_ms: u64) -> boolCheck if a cache entry is stale based on the given interval (in milliseconds).