pub fn read_cache(cache_dir: &Path, app_name: &str) -> Option<CacheEntry>Expand description
Read the cached update check for the given app.
Returns None on any error (missing file, invalid JSON, etc.).
pub fn read_cache(cache_dir: &Path, app_name: &str) -> Option<CacheEntry>Read the cached update check for the given app.
Returns None on any error (missing file, invalid JSON, etc.).