Module sources

Module sources 

Modules

brew_api
custom_manifest
github
jsr
npm_registry

Structs

FetchOptions
Options for fetching the latest version.
FetchVersionsOptions
Options for fetching a list of versions.
VersionInfo
Information about a specific version.

Enums

VersionListResult
Result of fetching a list of versions.
VersionSourceResult
Result of fetching the latest version from a source.

Traits

VersionSource
Trait for version sources that can check for updates.

Functions

create_version_source
Create a version source from a configuration variant.