Planner module — determines the update strategy based on install channel, confidence level, and available assets.
This is a pure module: no I/O, no side effects.
Structs
- Plan
Update Options - Options for
plan_update.
Functions
- expand_
asset_ pattern - Expand a placeholder-based asset pattern into a
Regex. - get_
arch_ aliases - Get architecture aliases for asset matching.
- get_
platform_ aliases - Get platform aliases for asset matching.
- plan_
update - Create an update plan based on version status, installation detection, and configuration.
- select_
asset - Select the appropriate asset for the current platform/architecture.