plan_update

Function plan_update 

pub fn plan_update(
    status: &UpdateStatus,
    detection: &InstallDetection,
    config: &ResolvedConfig,
    options: Option<PlanUpdateOptions>,
) -> Option<UpdatePlan>
Create an update plan based on version status, installation detection, and configuration.

Returns None if no update is needed (status is not Available and no target_version specified, or the current and target versions are identical).