Module paths
update_
kit
0.1.12
Module paths
Module Items
Functions
In update_
kit::
platform
update_kit
::
platform
Module
paths
Functions

get_
default_
cache_
dir
Returns the default cache directory for the current platform.
get_
default_
config_
dir
Returns the default config directory for the current platform.