Module types

Module types 

Structs

AssetInfo
Information about a downloadable release asset.
Evidence
A piece of evidence supporting an install detection result.
InstallDetection
Result of detecting how the application was installed.
UpdatePlan
A complete update plan describing what to do and how.

Enums

ApplyProgress
Progress updates during the apply phase.
ApplyResult
The result of applying an update.
Channel
The install channel through which the application was installed.
CheckMode
Whether to check for updates synchronously or asynchronously.
Confidence
Confidence level for install detection.
DelegateMode
Whether a delegate command should be printed or executed.
OutputStream
Which output stream a command is writing to.
PlanKind
The strategy for applying an update.
PostAction
Action to take after applying an update.
UpdateStatus
The result of checking for updates.