Channel-aware self-update toolkit for CLI applications.
update-kit detects how an application was installed and manages self-updates
through a pipeline: Detection -> Check -> Plan -> Apply.
The main entry point is UpdateKit, which orchestrates the full pipeline.
Re-exports
pub use config::BaseConfig;pub use config::Hooks;pub use config::ResolvedConfig;pub use config::UpdateKitConfig;pub use config::VersionSourceConfig;pub use errors::UpdateKitError;pub use types::ApplyResult;pub use types::AssetInfo;pub use types::Channel;pub use types::CheckMode;pub use types::Confidence;pub use types::DelegateMode;pub use types::Evidence;pub use types::InstallDetection;pub use types::PlanKind;pub use types::PostAction;pub use types::UpdatePlan;pub use types::UpdateStatus;
Modules
- applier
- checker
- config
- constants
- detection
- errors
- planner
- Planner module — determines the update strategy based on install channel, confidence level, and available assets.
- platform
- types
- utils
- ux
Structs
- Update
Kit - The main orchestrator for the update-kit pipeline.