Modules
Structs
- Check
Update Options - Options for the check_update orchestrator.
Functions
- check_
update - Orchestrate an update check using the configured sources and cache.
- normalize_
version - Normalize a version string by stripping a leading ‘v’ and parsing with semver.
Returns
Noneif the version string is not valid semver.