Modules
Structs
- Fetch
Options - Options for fetching the latest version.
- Fetch
Versions Options - Options for fetching a list of versions.
- Version
Info - Information about a specific version.
Enums
- Version
List Result - Result of fetching a list of versions.
- Version
Source Result - Result of fetching the latest version from a source.
Traits
- Version
Source - Trait for version sources that can check for updates.
Functions
- create_
version_ source - Create a version source from a configuration variant.