pub fn plan_update(
status: &UpdateStatus,
detection: &InstallDetection,
config: &ResolvedConfig,
options: Option<PlanUpdateOptions>,
) -> Option<UpdatePlan>Expand description
Create an update plan based on version status, installation detection, and configuration.
Returns None if no update is needed (status is not Available and no target_version
specified, or the current and target versions are identical).