Structs
- Asset
Info - Information about a downloadable release asset.
- Evidence
- A piece of evidence supporting an install detection result.
- Install
Detection - Result of detecting how the application was installed.
- Update
Plan - A complete update plan describing what to do and how.
Enums
- Apply
Progress - Progress updates during the apply phase.
- Apply
Result - The result of applying an update.
- Channel
- The install channel through which the application was installed.
- Check
Mode - Whether to check for updates synchronously or asynchronously.
- Confidence
- Confidence level for install detection.
- Delegate
Mode - Whether a delegate command should be printed or executed.
- Output
Stream - Which output stream a command is writing to.
- Plan
Kind - The strategy for applying an update.
- Post
Action - Action to take after applying an update.
- Update
Status - The result of checking for updates.